@@ -4,7 +4,7 @@ import sqlalchemy
 DB_HOST = "localhost"
 DB_NAME = "TEST_DATABASE"
 DATABASE_URL = databases.DatabaseURL(
-    f"postgresql://DEV_USER:DEV_PASSWORD@{DB_HOST}:5432/{DB_NAME}"
+    f"postgresql+asyncpg://DEV_USER:DEV_PASSWORD@{DB_HOST}:5432/{DB_NAME}"
 )
 database = databases.Database(str(DATABASE_URL))
 metadata = sqlalchemy.MetaData()
